import QtQuick 2.3
import QtQuick.Window 2.2

// Le layout parent, qui est la fenêtre toute entière
Window {

    // On veut qu'elle soit visible
    visible: true

    // "Column" est la version Qt de LinearLayout avec une orientation verticale
    // (pour afficher des vues les unes au-dessus des autres)
    Column {
        // Identifiant de la vue (correspond à +id="column")
        id:column

        // Position de la vue : comme c'est la vue à la racine, on veut qu'elle occupe toute la fenêtre
        anchors.fill: parent;

        // "Row" est la version Qt de LinearLayout avec une orientation horizontale
        // (pour afficher des vues les unes à côté des autres)
        Row {
            // Identifiant
            id: row

            // On veut que la largeur soit la même que celle du parent (équivalent de width="match_parent")
            width: parent.width
            // Si on ne précise rien pour la hauteur, la hauteur sera celle des des objets que la vue
            // contient (équivalent de height="wrap_content")

            // Première zone de texte éditable (équivalent de EditText)
            TextInput {
                // Identifiant
                id: editText1
                // La largeur : en Android, on utilisait des poids pour que cette vue ait comme largeur la moitié
                // de la place restante ; ici, on va dire que la largeur est la moitié (/ 2) de la place restante
                // (parent.width - text1.width - buttonEqual.width), qui est la largeur totale du parent moins la
                // largeur des autres objets
                width: (parent.width - textViewPlus.width - buttonEqual.width) / 2
                // Hauteur fixée
                height: 30
                // Contenu initial
                text: "0"
                // Taile de la police
                font.pixelSize: 12
            }

            // Zone de texte non éditable, contenant le "+" (équivalent de TextView)
            Text {
                // Identifiant
                id: textViewPlus
                // Contenu
                text: "+"
                // Taille de la police
                font.pixelSize: 12
            }

            // Deuxième zone de texte éditable, fonctionnant sur le même principe que la première
            TextInput {
                id: editText2
                width: (parent.width - textViewPlus.width - buttonEqual.width) / 2
                height: 30
                text: "0"
                font.pixelSize: 12
            }

            // Bouton (équivalent de Button ;-) )
            Button {
                // Identifiant
                id: buttonEqual
                // Dimensions (codées en dur pour simplifier, mais bien entendu, ne pas faire ça !)
                width: 60
                height: 30
                // Texte affiché sur le bouton
                text: "="
                // Code exécuté lorsqu'on clique dessus (ésuivalent de onClick) :
                // en Android, on passerait le nom d'une méthode Java; en Qml, on peut passer le nom
                // d'une méthode JavaScript, ou mettre directement le code s'il est simple.
                // Ici, on lit le contenu des zones de texte éditables, on récupère les deux entiers correspondants,
                // on les ajoute, et on les met dans la zone de texte du résultat.
                onClicked: textViewRes.text = parseInt(editText1.text) + parseInt(editText2.text)
            }

        }

        // Zone de texte du résultat
        Text {
            // Identifiant
            id: textViewRes
            // Contenu initial
            text: "0"
            // Taille du texte
            font.pixelSize: 12
            // On veut que ce soit affiché au centre (horizontalement) de la vue parente
            // (équivalent de layout_gravity="center_horizontal")
            anchors.horizontalCenter: parent.horizontalCenter
        }
    }

}
